# Delphi Epidata API Client

This package provides a programmatic interface to
[Delphi](https://delphi.cmu.edu/)'s epidemiological data ("epidata")
API. Source code and usage information can be found at
[https://github.com/cmu-delphi/delphi-epidata](https://github.com/cmu-delphi/delphi-epidata).
